@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Core;
 {
-  $Net::HTTP::Spore::Core::VERSION = '0.05';
+  $Net::HTTP::Spore::Core::VERSION = '0.06';
 }
 
 use Net::HTTP::Spore::Meta;
@@ -17,16 +17,26 @@ Net::HTTP::Spore::Core
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
