@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Meta::Class;
 {
-  $Net::HTTP::Spore::Meta::Class::VERSION = '0.05';
+  $Net::HTTP::Spore::Meta::Class::VERSION = '0.06';
 }
 
 # ABSTRACT: metaclass for all API client
@@ -21,16 +21,26 @@ Net::HTTP::Spore::Meta::Class - metaclass for all API client
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
 =head1 DESCRIPTION
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
