@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Middleware::Auth::Header;
 {
-  $Net::HTTP::Spore::Middleware::Auth::Header::VERSION = '0.05';
+  $Net::HTTP::Spore::Middleware::Auth::Header::VERSION = '0.06';
 }
 
 # ABSTRACT: middleware for authentication with specific header
@@ -31,7 +31,7 @@ Net::HTTP::Spore::Middleware::Auth::Header - middleware for authentication with
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -46,10 +46,20 @@ version 0.05
 
 Net::HTTP::Spore::Middleware::Auth::Header is a middleware to handle authentication mechanism that requires a specific header name.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
