@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Middleware::Format::XML;
 {
-  $Net::HTTP::Spore::Middleware::Format::XML::VERSION = '0.05';
+  $Net::HTTP::Spore::Middleware::Format::XML::VERSION = '0.06';
 }
 
 # ABSTRACT: middleware for XML format
@@ -41,7 +41,7 @@ Net::HTTP::Spore::Middleware::Format::XML - middleware for XML format
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -56,10 +56,20 @@ This middleware will also deserialize content in the response. The deserialized
 
 =head1 EXAMPLES
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
