@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Middleware::Format::YAML;
 {
-  $Net::HTTP::Spore::Middleware::Format::YAML::VERSION = '0.05';
+  $Net::HTTP::Spore::Middleware::Format::YAML::VERSION = '0.06';
 }
 
 # ABSTRACT: middleware for YAML format
@@ -26,7 +26,7 @@ Net::HTTP::Spore::Middleware::Format::YAML - middleware for YAML format
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -41,10 +41,20 @@ This middleware will also deserialize content in the response. The deserialized
 
 =head1 EXAMPLES
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
