@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Middleware::Redirection;
 {
-  $Net::HTTP::Spore::Middleware::Redirection::VERSION = '0.05';
+  $Net::HTTP::Spore::Middleware::Redirection::VERSION = '0.06';
 }
 
 # ABSTRACT: Middleware for redirections
@@ -60,7 +60,7 @@ Net::HTTP::Spore::Middleware::Redirection - Middleware for redirections
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -80,10 +80,20 @@ This middleware let you define how many redirection your client should follow. B
 
 How many redirections the client should follow. Default is 5
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
