@@ -1,6 +1,6 @@
 package Net::HTTP::Spore::Middleware::UserAgent;
 {
-  $Net::HTTP::Spore::Middleware::UserAgent::VERSION = '0.05';
+  $Net::HTTP::Spore::Middleware::UserAgent::VERSION = '0.06';
 }
 
 # ABSTRACT: middleware to change the user-agent value
@@ -28,7 +28,7 @@ Net::HTTP::Spore::Middleware::UserAgent - middleware to change the user-agent va
 
 =head1 VERSION
 
-version 0.05
+version 0.06
 
 =head1 SYNOPSIS
 
@@ -39,10 +39,20 @@ version 0.05
 
 Net::HTTP::Spore::Middleware::UserAgent change the default value of the useragent.
 
-=head1 AUTHOR
+=head1 AUTHORS
+
+=over 4
+
+=item *
 
 franck cuny <franck@lumberjaph.net>
 
+=item *
+
+Ash Berlin <ash@cpan.org>
+
+=back
+
 =head1 COPYRIGHT AND LICENSE
 
 This software is copyright (c) 2012 by linkfluence.
